This module provides the main functionality for analyzing environment variables in a source code directory and comparing them with an environment file.
Structs
- Analysis
Result - Represents the results of an environment variable analysis.